unit Main;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  Db, DBTables, SMIBase, SMIWiz, StdCtrls, SMI2DS, Grids, DBGrids,
  ComCtrls, ExtCtrls;

type
  TfrmMain = class(TForm)
    lblNote: TLabel;
    SMIWizardDlg: TSMIWizardDlg;
    tblDestination: TTable;
    SMImportFromDataSet: TSMImportFromDataSet;
    tblExternal: TTable;
    pnlTop: TPanel;
    btnImport: TButton;
    btnAbout: TButton;
    PageControl: TPageControl;
    tsCountries: TTabSheet;
    DBGrid: TDBGrid;
    tsErrorLog: TTabSheet;
    lbErrorLog: TListBox;
    tsImportedValues: TTabSheet;
    lbImportedValues: TListBox;
    dSrcDestination: TDataSource;
    procedure SMIWizardDlgClose(Sender: TObject; var Action: TModalResult);
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure btnAboutClick(Sender: TObject);
    procedure SMIWizardDlgBeforeExecute(Sender: TObject);
    procedure SMIWizardDlgErrorEvent(Sender: TObject; Error: Exception;
      var Abort: Boolean);
    procedure SMIWizardDlgGetCellParams(Sender: TObject; Field: TField;
      var Value: Variant);
    procedure btnImportClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  frmMain: TfrmMain;

implementation

{$R *.DFM}
{$R winxp.res}

procedure TfrmMain.SMIWizardDlgClose(Sender: TObject;
  var Action: TModalResult);
begin
  {replace default data loading for DBase}
  if (Action = mrOk) and
     (SMIWizardDlg.TableType = teDBase) then
  begin
    {1. say that wizard is canceled (so real import process will be not started}
    Action := mrCancel;

    {2. use SMImportFromDataSet for data loading from one dataset to our target}
    {a. copy all properties which user defined in wizard}
    SMImportFromDataSet.Mappings.Assign(SMIWizardDlg.Mappings);
    SMImportFromDataSet.DatasetKeys := SMIWizardDlg.DatasetKeys;
    SMImportFromDataSet.DataFormats.Assign(SMIWizardDlg.DataFormats);
    SMImportFromDataSet.Options := SMIWizardDlg.Options;
    SMImportFromDataSet.Mode := SMIWizardDlg.Mode;

    {b. open defined external file in our dataset (maybe third-party like Apollo)
    PS: in my sample I used tblExternal}
    tblExternal.Close;
    tblExternal.DatabaseName := ExtractFilePath(SMIWizardDlg.SourceFileName);
    tblExternal.TableName := ExtractFileName(SMIWizardDlg.SourceFileName);
    tblExternal.Open;

    {c. define source and target datasets for data loading}
    SMImportFromDataSet.DataSet := SMIWizardDlg.DataSet;
    SMImportFromDataSet.SourceDataSet := tblExternal;

    {d. start an import process}
    SMImportFromDataSet.Execute;

    {e. close dataset which is assigned with external file}
    tblExternal.Close;
  end
end;

procedure TfrmMain.FormCreate(Sender: TObject);
begin
  tblDestination.DatabaseName := ExtractFilePath(Application.ExeName);
  tblDestination.Open;
end;

procedure TfrmMain.FormDestroy(Sender: TObject);
begin
  tblDestination.Close;
end;

procedure TfrmMain.btnAboutClick(Sender: TObject);
begin
  SMIWizardDlg.AboutSMI
end;

procedure TfrmMain.SMIWizardDlgBeforeExecute(Sender: TObject);
begin
  lbErrorLog.Items.Clear;
  lbImportedValues.Items.Clear;
end;

procedure TfrmMain.SMIWizardDlgErrorEvent(Sender: TObject;
  Error: Exception; var Abort: Boolean);
begin
  if lbErrorLog.Items.Count < 30000 then
    lbErrorLog.Items.Add(Error.Message);
end;

procedure TfrmMain.SMIWizardDlgGetCellParams(Sender: TObject;
  Field: TField; var Value: Variant);
begin
  if lbImportedValues.Items.Count < 30000 then
    lbImportedValues.Items.Add(Field.FieldName + ' = ' + VarToStr(Value));
end;

procedure TfrmMain.btnImportClick(Sender: TObject);
begin
  SMIWizardDlg.Execute
end;

end.
